create_backend

Function create_backend 

fn create_backend<N: Network, BLOCK: FoundryBlock + ForkBlockEnv>(
    fork: &CreateFork,
    resolved: &Fork,
    block_env: &BLOCK,
) -> Result<(SharedBackend<N, BLOCK>, BackendHandler<N, BLOCK>)>
Creates the backend of a resolved fork.

This loads the disk cache of the fork block, so it only runs for a new fork ID.