create_fork

Function create_fork 

async fn create_fork<SPEC: Into<SpecId> + Default + Copy + Send, BLOCK: FoundryBlock + ForkBlockEnv + Default>(
    fork: CreateFork,
    expected_identity: Option<ForkContext>,
    prewarm_bal: bool,
    exact_block: Option<(Fork, BlockNumHash)>,
) -> Result<(ForkId, CreateFork, Fork, EvmEnv<SPEC, BLOCK>, Option<BlockAccessList>)>
Creates a new fork.

This resolves the fork block and environment through the endpoint. The handler creates the backend with create_backend only if no backend exists for the fork ID.