async fn create_fork<N: Network>(
fork: CreateFork,
) -> Result<(ForkId, CreatedFork<N>, BackendHandler<N>)>Expand description
Creates a new fork.
This will establish a new Provider to the endpoint and return the Fork Backend.
async fn create_fork<N: Network>(
fork: CreateFork,
) -> Result<(ForkId, CreatedFork<N>, BackendHandler<N>)>Creates a new fork.
This will establish a new Provider to the endpoint and return the Fork Backend.